#
# spec file for package python-pytest-httpbin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-httpbin
Version:        2.0.0
Release:        1.6
Summary:        Web service for testing HTTP libraries
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/kevin1024/pytest-httpbin
Source:         https://files.pythonhosted.org/packages/source/p/pytest-httpbin/pytest-httpbin-%{version}.tar.gz
Source99:       pytest-httpbin-rpmlintrc
BuildRequires:  %{python_module httpbin}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-httpbin
Requires:       python-pytest
BuildArch:      noarch
%python_subpackages

%description
httpbin is a web service for testing HTTP libraries. It has several
endpoints that can test parts needed in a HTTP library.

Pytest-httpbin creates a pytest "fixture" that is
dependency-injected into your tests. It automatically starts up a HTTP server
in a separate thread running httpbin and provides your test with the URL in the
fixture.

%prep
%autosetup -p1 -n pytest-httpbin-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Flask 2.1 returns relative URLs again
# gh#kevin1024/pytest-httpbin#64
%pytest -k "not test_redirect_location_is_https_for_secure_server"

%files %{python_files}
%doc README.md DESCRIPTION.rst
%{python_sitelib}/pytest_httpbin
%{python_sitelib}/pytest_httpbin-%{version}*-info

%changelog
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * This is a major release since it drops comparability with
    some older versions of python.
  * Drop support for Python 2.6, 2.7, 3.4, 3.5 and 3.6 (#68)
  * Add support for Python 3.7, 3.8, 3.9 and 3.10 (#68)
  * Avoid deprecation warnings and resource warnings (#71)
  * Add support for Python 3.11 and 3.12, drop dependency on six
- drop python-pytest-httpbin-no-six.patch (upstream)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Dec  8 2022 pgajdos@suse.com
- do not require six
- added patches
  fix https://github.com/kevin1024/pytest-httpbin/issues/75
  + python-pytest-httpbin-no-six.patch
* Tue Apr 12 2022 Ben Greiner <code@bnavigator.de>
- Skip a test which fails with Flask 2.1
  gh#kevin1024/pytest-httpbin#64
* Fri Apr  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Switch to GitHub Actions
  * This will be the last release to support Python 2.6, 2.7 or 3.6
* Wed Dec 29 2021 Ben Greiner <code@bnavigator.de>
- Update to v1.0.1
  * httpbin_secure: fix redirect Location to have "https://"
    scheme (#62) - thanks @immerrr
  * Include regression tests in pypi tarball (#56) - thanks
    @kmosiejczuk
- Add rpmlintrc filter for test certificates
* Fri Feb 15 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.0:
  * Update included self-signed cert to include IP address in SAN (See #52).
  * Only use @pytest.fixture decorator once (thanks @hroncok)
  * Fix a few README typos (thanks @hemberger)
- Use github tarball to get tests
* Wed May  2 2018 tchvatal@suse.com
- Revert last commit
* Thu Apr 19 2018 toddrme2178@gmail.com
- Fix dependencies.
* Mon Nov 13 2017 arun@gmx.de
- removed 0001-Remove-Flask-and-decorator-from-install_requires.patch
  (included upstream)
- update to version 0.3.0:
  * Allow to run httpbin on fixed port using environment variables
    (thanks @hroncok)
  * Allow server to be thread.join()ed (thanks @graingert)
  * Add support for Python 3.6 (thanks @graingert)
* Tue Aug  8 2017 tbechtold@suse.com
- add 0001-Remove-Flask-and-decorator-from-install_requires.patch
- cleanup Requires
* Sun May  7 2017 jengelh@inai.de
- Remove sensationalist language from description.
* Tue Apr  4 2017 jmatejek@suse.com
- initial commit - test requirement of python-requests
